// 
// Copyright (C) 2009, GreatTradingSystems <www.greattradingsystems.com>.
// 
//
#region Using declarations
using System;
using System.Diagnostics;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.ComponentModel;
using System.Xml.Serialization;
using NinjaTrader.Cbi;
using NinjaTrader.Data;
using NinjaTrader.Gui.Chart;
#endregion

// This namespace holds all indicators and is required. Do not change it.
namespace NinjaTrader.Indicator
{
    /// <summary>
    /// This is a sample indicator plotting a HMA in three colors.
    /// </summary>
    [Description("Sample HMA plotted with three colors.")]
    [Gui.Design.DisplayName("HMAColourChange")]
    public class HMAColourChange : Indicator
    {
		#region Variables
		private int		period	= 14;
		#endregion
		
        /// <summary>
        /// This method is used to configure the indicator and is called once before any bar data is loaded.
        /// </summary>
        protected override void Initialize()
        {
			// Add one plot for every color you wish to use.
            Add(new Plot(Color.LimeGreen, PlotStyle.Line, "Rising"));
            Add(new Plot(Color.Red, PlotStyle.Line, "Falling"));
			Add(new Plot(Color.Yellow, PlotStyle.Line, "Neutral"));
			
            CalculateOnBarClose	= true;
            Overlay				= true;
        }

        /// <summary>
        /// Called on each bar update event (incoming tick)
        /// </summary>
        protected override void OnBarUpdate()
        {
			// Checks to make sure we have at least 1 bar before continuing
			if (CurrentBar < 1)
				return;
			
			// Plot green if the HMA is rising
			// Rising() returns true when the current value is greater than the value of the previous bar.
			if (Rising(HMA(Period)))
			{
				// Connects the rising plot segment with the other plots
				RisingPlot.Set(1, HMA(Period)[1]);
				
				// Adds the new rising plot line segment to the line
				RisingPlot.Set(HMA(Period)[0]);
			}
			
			// Plot red if the HMA is falling
			// Falling() returns true when the current value is less than the value of the previous bar.
			else if (Falling(HMA(Period)))
			{
				// Connects the new falling plot segment with the rest of the line
				FallingPlot.Set(1, HMA(Period)[1]);
				
				// Adds the new falling plot line segment to the line
				FallingPlot.Set(HMA(Period)[0]);
			}
			
			// Plot yellow if the HMA is neutral
			else
			{
				// Connects the neutral plot segment with the rest of the line
				NeutralPlot.Set(1, HMA(Period)[1]);
				
				// Adds the new neutral plot line segment to the line
				NeutralPlot.Set(HMA(Period)[0]);
			}
        }

        #region Properties
		// Adds three DataSeries to store the values of the three plots added in Initialize()
        [Browsable(false)]	// this line prevents the data series from being displayed in the indicator properties dialog, do not remove
        [XmlIgnore()]		// this line ensures that the indicator can be saved/recovered as part of a chart template, do not remove
        public DataSeries RisingPlot
        {
            get { return Values[0]; }
        }

        [Browsable(false)]	// this line prevents the data series from being displayed in the indicator properties dialog, do not remove
        [XmlIgnore()]		// this line ensures that the indicator can be saved/recovered as part of a chart template, do not remove
        public DataSeries FallingPlot
        {
            get { return Values[1]; }
        }
		
		[Browsable(false)]	// this line prevents the data series from being displayed in the indicator properties dialog, do not remove
        [XmlIgnore()]		// this line ensures that the indicator can be saved/recovered as part of a chart template, do not remove
        public DataSeries NeutralPlot
        {
            get { return Values[2]; }
        }
		
		// Adds an input for the period of the SMA
		/// <summary>
		/// </summary>
		[Description("Numbers of bars used for calculations")]
		[Category("Parameters")]
		public int Period
		{
			get { return period; }
			set { period = Math.Max(1, value); }
		}
        #endregion
    }
}

#region NinjaScript generated code. Neither change nor remove.
// This namespace holds all indicators and is required. Do not change it.
namespace NinjaTrader.Indicator
{
    public partial class Indicator : IndicatorBase
    {
        private HMAColourChange[] cacheHMAColourChange = null;

        private static HMAColourChange checkHMAColourChange = new HMAColourChange();

        /// <summary>
        /// Sample HMA plotted with three colors.
        /// </summary>
        /// <returns></returns>
        public HMAColourChange HMAColourChange(int period)
        {
            return HMAColourChange(Input, period);
        }

        /// <summary>
        /// Sample HMA plotted with three colors.
        /// </summary>
        /// <returns></returns>
        public HMAColourChange HMAColourChange(Data.IDataSeries input, int period)
        {
            checkHMAColourChange.Period = period;
            period = checkHMAColourChange.Period;

            if (cacheHMAColourChange != null)
                for (int idx = 0; idx < cacheHMAColourChange.Length; idx++)
                    if (cacheHMAColourChange[idx].Period == period && cacheHMAColourChange[idx].EqualsInput(input))
                        return cacheHMAColourChange[idx];

            HMAColourChange indicator = new HMAColourChange();
            indicator.BarsRequired = BarsRequired;
            indicator.CalculateOnBarClose = CalculateOnBarClose;
            indicator.Input = input;
            indicator.Period = period;
            indicator.SetUp();

            HMAColourChange[] tmp = new HMAColourChange[cacheHMAColourChange == null ? 1 : cacheHMAColourChange.Length + 1];
            if (cacheHMAColourChange != null)
                cacheHMAColourChange.CopyTo(tmp, 0);
            tmp[tmp.Length - 1] = indicator;
            cacheHMAColourChange = tmp;
            Indicators.Add(indicator);

            return indicator;
        }

    }
}

// This namespace holds all market analyzer column definitions and is required. Do not change it.
namespace NinjaTrader.MarketAnalyzer
{
    public partial class Column : ColumnBase
    {
        /// <summary>
        /// Sample HMA plotted with three colors.
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.HMAColourChange HMAColourChange(int period)
        {
            return _indicator.HMAColourChange(Input, period);
        }

        /// <summary>
        /// Sample HMA plotted with three colors.
        /// </summary>
        /// <returns></returns>
        public Indicator.HMAColourChange HMAColourChange(Data.IDataSeries input, int period)
        {
            return _indicator.HMAColourChange(input, period);
        }

    }
}

// This namespace holds all strategies and is required. Do not change it.
namespace NinjaTrader.Strategy
{
    public partial class Strategy : StrategyBase
    {
        /// <summary>
        /// Sample HMA plotted with three colors.
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.HMAColourChange HMAColourChange(int period)
        {
            return _indicator.HMAColourChange(Input, period);
        }

        /// <summary>
        /// Sample HMA plotted with three colors.
        /// </summary>
        /// <returns></returns>
        public Indicator.HMAColourChange HMAColourChange(Data.IDataSeries input, int period)
        {
            if (InInitialize && input == null)
                throw new ArgumentException("You only can access an indicator with the default input/bar series from within the 'Initialize()' method");

            return _indicator.HMAColourChange(input, period);
        }

    }
}
#endregion
