#region Using declarations
using System;
using System.Diagnostics;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.ComponentModel;
using System.Xml.Serialization;
using NinjaTrader.Cbi;
using NinjaTrader.Data;
using NinjaTrader.Gui.Chart;
#endregion

// This namespace holds all indicators and is required. Do not change it.
namespace NinjaTrader.Indicator
{
    /// <summary>
    /// 
    /// </summary>
    [Description("")]
    public class InverseFisherTransform : Indicator
    {
        #region Variables
        // Wizard generated variables
            private int period = 5; // Default setting for Period
        // User defined variables (add any user defined variables below)
			private DataSeries V1;
        #endregion

        /// <summary>
        /// This method is used to configure the indicator and is called once before any bar data is loaded.
        /// </summary>
        protected override void Initialize()
        {
            Add(new Plot(Color.FromKnownColor(KnownColor.Orange), PlotStyle.Line, "Plot0"));
            Add(new Line(Color.FromKnownColor(KnownColor.Cyan), 0.50, "UpTrend"));
            Add(new Line(Color.FromKnownColor(KnownColor.IndianRed), -0.5, "DownTrend"));
            CalculateOnBarClose	= true;
            Overlay				= false;
            PriceTypeSupported	= false;
			V1 = new DataSeries(this);
        }

        /// <summary>
        /// Called on each bar update event (incoming tick)
        /// </summary>
        protected override void OnBarUpdate()
        {
            // Use this method for calculating your indicator values. Assign a value to each
            // plot below by replacing 'Close[0]' with your own formula.
			V1.Set(0.1*(RSI(period,1)[0]-50));
			double v2=WMA(V1,9)[0];
			Plot0.Set((Math.Exp(2*v2)-1)/(Math.Exp(2*v2)+1));
        }

        #region Properties
        [Browsable(false)]	// this line prevents the data series from being displayed in the indicator properties dialog, do not remove
        [XmlIgnore()]		// this line ensures that the indicator can be saved/recovered as part of a chart template, do not remove
        public DataSeries Plot0
        {
            get { return Values[0]; }
        }

        [Description("")]
        [Category("Parameters")]
        public int Period
        {
            get { return period; }
            set { period = Math.Max(1, value); }
        }
        #endregion
    }
}


#region NinjaScript generated code. Neither change nor remove.
// This namespace holds all indicators and is required. Do not change it.
namespace NinjaTrader.Indicator
{
    public partial class Indicator : IndicatorBase
    {
        private InverseFisherTransform[] cacheInverseFisherTransform = null;

        private static InverseFisherTransform checkInverseFisherTransform = new InverseFisherTransform();

        /// <summary>
        /// 
        /// </summary>
        /// <returns></returns>
        public InverseFisherTransform InverseFisherTransform(int period)
        {
            return InverseFisherTransform(Input, period);
        }

        /// <summary>
        /// 
        /// </summary>
        /// <returns></returns>
        public InverseFisherTransform InverseFisherTransform(Data.IDataSeries input, int period)
        {
            checkInverseFisherTransform.Period = period;
            period = checkInverseFisherTransform.Period;

            if (cacheInverseFisherTransform != null)
                for (int idx = 0; idx < cacheInverseFisherTransform.Length; idx++)
                    if (cacheInverseFisherTransform[idx].Period == period && cacheInverseFisherTransform[idx].EqualsInput(input))
                        return cacheInverseFisherTransform[idx];

            InverseFisherTransform indicator = new InverseFisherTransform();
            indicator.SetUp();
            indicator.CalculateOnBarClose = CalculateOnBarClose;
            indicator.Input = input;
            indicator.Period = period;

            InverseFisherTransform[] tmp = new InverseFisherTransform[cacheInverseFisherTransform == null ? 1 : cacheInverseFisherTransform.Length + 1];
            if (cacheInverseFisherTransform != null)
                cacheInverseFisherTransform.CopyTo(tmp, 0);
            tmp[tmp.Length - 1] = indicator;
            cacheInverseFisherTransform = tmp;
            Indicators.Add(indicator);

            return indicator;
        }

    }
}

// This namespace holds all market analyzer column definitions and is required. Do not change it.
namespace NinjaTrader.MarketAnalyzer
{
    public partial class Column : ColumnBase
    {
        /// <summary>
        /// 
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.InverseFisherTransform InverseFisherTransform(int period)
        {
            return _indicator.InverseFisherTransform(Input, period);
        }

        /// <summary>
        /// 
        /// </summary>
        /// <returns></returns>
        public Indicator.InverseFisherTransform InverseFisherTransform(Data.IDataSeries input, int period)
        {
            return _indicator.InverseFisherTransform(input, period);
        }

    }
}

// This namespace holds all strategies and is required. Do not change it.
namespace NinjaTrader.Strategy
{
    public partial class Strategy : StrategyBase
    {
        /// <summary>
        /// 
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.InverseFisherTransform InverseFisherTransform(int period)
        {
            return _indicator.InverseFisherTransform(Input, period);
        }

        /// <summary>
        /// 
        /// </summary>
        /// <returns></returns>
        public Indicator.InverseFisherTransform InverseFisherTransform(Data.IDataSeries input, int period)
        {
            if (InInitialize && input == null)
                throw new ArgumentException("You only can access an indicator with the default input/bar series from within the 'Initialize()' method");

            return _indicator.InverseFisherTransform(input, period);
        }

    }
}
#endregion
